@@ -18,9 +18,6 @@ model <- "A =~ A1+A2+A3+A4+A5;
 n <- 50
 object <- lavaan::sem(model, psych::bfi[1:n, 1:10], estimator = "MLM")
 
-data <- bollen_stine_transform(m0)
-
-
 ## Estimation that isn't allowed.
 m1_ <- lavaan::cfa(hs_model,
   data = lavaan::HolzingerSwineford1939,
@@ -31,3 +28,19 @@ m0_ <- lavaan::cfa(hs_model,
   data = lavaan::HolzingerSwineford1939,
   group = "school", estimator = "GLS", group.equal = "loadings"
 )
+
+
+
+## Nested without groups
+
+hs_model_no_groups <- " visual  =~ x1 + a*x2 + x3
+              textual =~ x4 + a*x5 + a*x6
+              speed   =~ x7 + a*x8 + x9 "
+
+m1_no_groups <- lavaan::cfa(hs_model,
+                  data = lavaan::HolzingerSwineford1939, estimator = "MLM"
+)
+
+m0_no_groups <- lavaan::cfa(hs_model_no_groups,
+                  data = lavaan::HolzingerSwineford1939, estimator = "MLM"
+)
